package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.modelPic.EModelPic;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.service.IEModelPicService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 车辆型号图片Controller
 *
 * @author qzz
 * @date 2024-12-30
 */
@RestController
@RequestMapping("/system/modelPic")
public class EModelPicController extends BaseController
{
    @Autowired
    private IEModelPicService eModelPicService;

    /**
     * 查询车辆型号图片列表
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:list')")
    @GetMapping("/list")
    public TableDataInfo list(EModelPic eModelPic)
    {
        startPage();
        List<EModelPic> list = eModelPicService.selectEModelPicList(eModelPic);
        return getDataTable(list);
    }

    /**
     * 导出车辆型号图片列表
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:export')")
    @Log(title = "车辆型号图片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EModelPic eModelPic)
    {
        List<EModelPic> list = eModelPicService.selectEModelPicList(eModelPic);
        ExcelUtil<EModelPic> util = new ExcelUtil<EModelPic>(EModelPic.class);
        util.exportExcel(response, list, "车辆型号图片数据");
    }

    /**
     * 获取车辆型号图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:query')")
    @GetMapping(value = "/{modelId}")
    public AjaxResult getInfo(@PathVariable("modelId") Long modelId)
    {
        return success(eModelPicService.selectEModelPicByModelId(modelId));
    }

    /**
     * 新增车辆型号图片
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:add')")
    @Log(title = "车辆型号图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EModelPic eModelPic)
    {
        return toAjax(eModelPicService.insertEModelPic(eModelPic));
    }

    /**
     * 修改车辆型号图片
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:edit')")
    @Log(title = "车辆型号图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EModelPic eModelPic)
    {
        return toAjax(eModelPicService.updateEModelPic(eModelPic));
    }

    /**
     * 删除车辆型号图片
     */
    @PreAuthorize("@ss.hasPermi('system:modelPic:remove')")
    @Log(title = "车辆型号图片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{modelIds}")
    public AjaxResult remove(@PathVariable Long[] modelIds)
    {
        return toAjax(eModelPicService.deleteEModelPicByModelIds(modelIds));
    }
}
